<?php
require('config.php'); // Includes the PDO connection
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        // Start a transaction
        $pdo->beginTransaction();

        // Handle file uploads
        $applicantImage = $_FILES['applicant_photo']['name'];
        $applicationFile = $_FILES['application_file']['name'];
        $premisesImages = $_FILES['premises_image'];

        // Define target directories
        $applicantImageDir = "../../static/dealer_data/applicants_img/";
        $applicationFileDir = "../../static/dealer_data/applicants_forms/";
        $premisesImagesDir = "../../static/dealer_data/premises_imges/";

        // Move uploaded files to respective directories
        if ($applicantImage) {
            $applicantImageTarget = $applicantImageDir . basename($applicantImage);
            if (!move_uploaded_file($_FILES['applicant_photo']['tmp_name'], $applicantImageTarget)) {
                throw new Exception("Failed to upload applicant photo.");
            }
        }
        if ($applicationFile) {
            $applicationFileTarget = $applicationFileDir . basename($applicationFile);
            if (!move_uploaded_file($_FILES['application_file']['tmp_name'], $applicationFileTarget)) {
                throw new Exception("Failed to upload application file.");
            }
        }

        // Handle premises images
        $premisesImagePaths = [];
        if (isset($premisesImages['name']) && is_array($premisesImages['name'])) {
        for ($i = 0; $i < count($premisesImages['name']); $i++) {
            if ($premisesImages['name'][$i]) {
                $premisesImageName = basename($premisesImages['name'][$i]);
                $premisesImageTarget = $premisesImagesDir . $premisesImageName;
                if (!move_uploaded_file($premisesImages['tmp_name'][$i], $premisesImageTarget)) {
                    throw new Exception("Failed to upload premises image: " . $premisesImages['name'][$i]);
                }
                $premisesImagePaths[] = $premisesImageName;
            }
        }
        }
        else{
            echo 'No files were uploaded or the input field is not an array.';
        }

        // Insert into dealer_applicant table
        $stmt = $pdo->prepare("
            INSERT INTO dealer_applicant 
            (applicant_image, application_pdf_path, total_promoters, name, email, dob, mobile_number, age, gender, marital_status, aadhar_number, pin_code, citizenship, state, city, created_at) 
            VALUES 
            (:applicant_image, :application_pdf_path, :total_promoters, :name, :email, :dob, :mobile_number, :age, :gender, :marital_status, :aadhar_number, :pin_code, :citizenship, :state, :city, NOW())
        ");

        $stmt->execute([
            ':applicant_image' => $applicantImage,
            ':application_pdf_path' => $applicationFile,
            ':total_promoters' => $_POST['promotors'],
            ':name' => $_POST['name'],
            ':email' => $_POST['email'],
            ':dob' => $_POST['dob'],
            ':mobile_number' => $_POST['mobile'],
            ':age' => $_POST['age'],
            ':gender' => $_POST['sex'],
            ':marital_status' => $_POST['marital_status'],
            ':aadhar_number' => $_POST['adhar_card'],
            ':pin_code' => $_POST['residence_pin'],
            ':citizenship' => $_POST['citizenship'],
            ':state' => $_POST['state'],
            ':city' => $_POST['city']
        ]);

        // Get the last inserted applicant_id
        $applicant_id = $pdo->lastInsertId();
        if (!$applicant_id) {
            throw new Exception("Failed to retrieve applicant ID.");
        }

        // Insert into dealer_residence_details table
        $stmt = $pdo->prepare("
            INSERT INTO dealer_residence_details 
            (applicant_id, residence_email, residence_mobile, residence_telephone, residence_fax, residence_address, residence_pin_code) 
            VALUES 
            (:applicant_id, :residence_email, :residence_mobile, :residence_telephone, :residence_fax, :residence_address, :residence_pin_code)
        ");

        $stmt->execute([
            ':applicant_id' => $applicant_id,
            ':residence_email' => $_POST['residence_email'],
            ':residence_mobile' => $_POST['residence_mobile'],
            ':residence_telephone' => $_POST['residence_telephone'],
            ':residence_fax' => $_POST['residence_fax'],
            ':residence_address' => $_POST['residence_address'],
            ':residence_pin_code' => $_POST['residence_pin']
        ]);

        // Insert into dealer_office_details table
        $stmt = $pdo->prepare("
            INSERT INTO dealer_office_details 
            (applicant_id, office_email, office_mobile, office_telephone, office_fax, office_pin_code) 
            VALUES 
            (:applicant_id, :office_email, :office_mobile, :office_telephone, :office_fax, :office_pin_code)
        ");

        $stmt->execute([
            ':applicant_id' => $applicant_id,
            ':office_email' => $_POST['office_email'],
            ':office_mobile' => $_POST['office_mobile'],
            ':office_telephone' => $_POST['office_telephone'],
            ':office_fax' => $_POST['office_fax'],
            ':office_pin_code' => $_POST['office_pin']
        ]);

        // Insert into dealer_education table (Multiple entries)
        if (!empty($_POST['education']) && is_array($_POST['education'])) {
            $stmt = $pdo->prepare("
                INSERT INTO dealer_education 
                (applicant_id, degree, institute, year_of_passing) 
                VALUES 
                (:applicant_id, :degree, :institute, :year_of_passing)
            ");

            foreach ($_POST['education'] as $index => $degree) {
                $stmt->execute([
                    ':applicant_id' => $applicant_id,
                    ':degree' => $degree,
                    ':institute' => $_POST['institute'][$index],
                    ':year_of_passing' => $_POST['year_of_passout'][$index]
                ]);
            }
        }

        // Insert into dealer_existing_business table
        if ($_POST['automobile_dealership'] == 'Yes') {
            $stmt = $pdo->prepare("
                INSERT INTO dealer_existing_business 
                (applicant_id, business_name, business_email, business_mobile, total_years_business, total_turnover, net_worth, three_year_itr) 
                VALUES 
                (:applicant_id, :business_name, :business_email, :business_mobile, :total_years_business, :total_turnover, :net_worth, :three_year_itr)
            ");

            $stmt->execute([
                ':applicant_id' => $applicant_id,
                ':business_name' => $_POST['existing_business_name'],
                ':business_email' => $_POST['existing_business_email'],
                ':business_mobile' => $_POST['existing_business_mobile'],
                ':total_years_business' => $_POST['total_years_business'],
                ':total_turnover' => $_POST['total_turnover'],
                ':net_worth' => $_POST['net_worth'],
                ':three_year_itr' => $_POST['three_year_itr']
            ]);

            $business_id = $pdo->lastInsertId();
            if (!$business_id) {
                throw new Exception("Failed to retrieve business ID.");
            }

            // Insert into dealer_automobile_details table
            $stmt = $pdo->prepare("
                INSERT INTO dealer_automobile_details 
                (business_id, annual_profit, assets, dealership_name, product_brand, nature_of_business, stake, annual_turnover, spare_parts_sales_per_month, product_sales_per_month, number_of_employees, number_of_promotors, total_investment_in_lakhs) 
                VALUES 
                (:business_id, :annual_profit, :assets, :dealership_name, :product_brand, :nature_of_business, :stake, :annual_turnover, :spare_parts_sales, :product_sales, :number_of_employees, :number_of_promotors, :total_investment_in_lakhs)
            ");

            $stmt->execute([
                ':business_id' => $business_id,
                ':annual_profit' => $_POST['business_profit'],
                ':assets' => $_POST['business_assets'],
                ':dealership_name' => $_POST['existing_business_name'],
                ':product_brand' => $_POST['product_brand'],
                ':nature_of_business' => $_POST['nature_of_business'],
                ':stake' => $_POST['stake'],
                ':annual_turnover' => $_POST['annual_turnover'],
                ':spare_parts_sales' => $_POST['spare_parts_sales'],
                ':product_sales' => $_POST['product_sales'],
                ':number_of_employees' => $_POST['no_of_employees'],
                ':number_of_promotors' => $_POST['no_of_promotors'],
                ':total_investment_in_lakhs' => $_POST['total_investment']
            ]);
        }

        // Insert into dealer_proposed_premises table
        $stmt = $pdo->prepare("
            INSERT INTO dealer_proposed_premises 
            (applicant_id, firm_name, constitution, address, premises_type, area) 
            VALUES 
            (:applicant_id, :firm_name, :constitution, :address, :premises_type, :area)
        ");

        $stmt->execute([
            ':applicant_id' => $applicant_id,
            ':firm_name' => $_POST['firm_name'],
            ':constitution' => $_POST['constitution'],
            ':address' => $_POST['premises_address'],
            ':premises_type' => $_POST['premises_type'],
            ':area' => $_POST['area']
        ]);

        $premises_id = $pdo->lastInsertId();
        if (!$premises_id) {
            throw new Exception("Failed to retrieve premises ID.");
        }

        // Insert into dealer_sales_projection table
        if (!empty($_POST['sales_projection']) && is_array($_POST['sales_projection'])) {
            $stmt = $pdo->prepare("
                INSERT INTO dealer_sales_projection 
                (premises_id, year, annual_sales_volume) 
                VALUES 
                (:premises_id, :year, :annual_sales_volume)
            ");

            foreach ($_POST['sales_projection'] as $index => $year) {
                $stmt->execute([
                    ':premises_id' => $premises_id,
                    ':year' => $year,
                    ':annual_sales_volume' => $_POST['annual_sales_volume'][$index]
                ]);
            }
        }

        // Insert into dealer_premises_images table
        foreach ($premisesImagePaths as $imageName) {
            $stmt = $pdo->prepare("
                INSERT INTO dealer_premises_images 
                (premises_id, image_name) 
                VALUES 
                (:premises_id, :image_name)
            ");

            $stmt->execute([
                ':premises_id' => $premises_id,
                ':image_name' => $imageName
            ]);
        }

        // Insert into dealer_finance table
        $stmt = $pdo->prepare("
            INSERT INTO dealer_finance 
            (applicant_id, investment_amount, investment_term_loan, investment_term_from, capital_amount, capital_term_loan, capital_term_from) 
            VALUES 
            (:applicant_id, :investment_amount, :investment_term_loan, :investment_term_from, :capital_amount, :capital_term_loan, :capital_term_from)
        ");

        $stmt->execute([
            ':applicant_id' => $applicant_id,
            ':investment_amount' => $_POST['investment_amount'],
            ':investment_term_loan' => $_POST['investment_term_loan'],
            ':investment_term_from' => $_POST['investment_term_from'],
            ':capital_amount' => $_POST['capital_amount'],
            ':capital_term_loan' => $_POST['capital_term_loan'],
            ':capital_term_from' => $_POST['capital_term_from']
        ]);

        // Commit the transaction
        $pdo->commit();
        echo "Application submitted successfully.";
    } catch (Exception $e) {
        // Rollback the transaction if something failed
        $pdo->rollBack();
        echo "Failed to submit application: " . $e->getMessage();
    }
}
?>
