<?php
class Career
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    public function storeResumeData($full_name, $email, $mobile, $job_role_id, $country, $experience, $resume)
    {
        try {

            $resume_folder = "upload_resumes/";

            if (!is_dir($resume_folder)) {
                mkdir($resume_folder, 0777, true);
            }


            $file = $resume_folder . basename($resume["name"]);
            $fileType = strtolower(pathinfo($file, PATHINFO_EXTENSION));


            $allowed_types = ['pdf', 'doc', 'docx'];

            if (!in_array($fileType, $allowed_types)) {
                throw new Exception("Sorry, only PDF, DOC, & DOCX files are allowed.");
            }

            if (move_uploaded_file($resume["tmp_name"], $file)) {

                $stmt = $this->pdo->prepare(
                    "INSERT INTO careers (full_name, email, mobile, job_role_id, country, experience, resume, created) 
                    VALUES (:full_name, :email, :mobile, :job_role_id, :country, :experience, :resume, :created)"
                );


                $stmt->execute([
                    ':full_name' => $full_name,
                    ':email' => $email,
                    ':mobile' => $mobile,
                    ':job_role_id' => $job_role_id,
                    ':country' => $country,
                    ':experience' => $experience,
                    ':resume' => basename($resume["name"]),
                    ':created' => date('Y-m-d')
                ]);


                return $stmt->rowCount() == 1;
            } else {
                throw new Exception("Sorry, there was an error uploading your file.");
            }
        } catch (Exception $e) {

            return $e->getMessage();
        }
    }

    public function jobCategories()
    {
        try {
            $stmt = $this->pdo->prepare("SELECT job_category.id, job_category.category_name, user_accounts.name
                                        FROM job_category
                                        JOIN user_accounts ON job_category.user_id = user_accounts.id ORDER BY id DESC");
            $stmt->execute();
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            return false;
        }
    }

    public function fetchAllJobPostsGroupedByJobType()
    {
        try {
            // Prepare the SQL query to join job_posts, job_type, job_designations, job_departments, and job_divisions tables
            $stmt = $this->pdo->prepare("
            SELECT jp.*, 
                   jt.name AS job_type_name, 
                   jt.id AS job_type_id,
                   jd.name AS designation_name,
                   jdpt.name AS department_name,
                   jdiv.name AS division_name
            FROM job_posts jp
            INNER JOIN job_type jt ON jp.job_type = jt.id
            INNER JOIN job_designations jd ON jp.job_designation_id = jd.id
            INNER JOIN job_departments jdpt ON jp.job_department_id = jdpt.id
            INNER JOIN job_divisions jdiv ON jp.job_division_id = jdiv.id
        ");

            // Execute the query
            $stmt->execute();

            // Fetch all results
            $jobPosts = $stmt->fetchAll(PDO::FETCH_ASSOC);

            // Group job posts by job type
            $groupedJobPosts = [];
            foreach ($jobPosts as $jobPost) {
                $jobTypeName = $jobPost['job_type_name'];
                $jobTypeId = $jobPost['job_type_id'];
                if (!isset($groupedJobPosts[$jobTypeName])) {
                    $groupedJobPosts[$jobTypeName] = [
                        'id' => $jobTypeId,
                        'posts' => []
                    ];
                }
                $groupedJobPosts[$jobTypeName]['posts'][] = $jobPost;
            }

            return $groupedJobPosts;
        } catch (Exception $e) {
            // Return the exception message in case of an error
            return $e->getMessage();
        }
    }
}
