<?php
class Complaints
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    public function storeComplain($firstName, $lastName, $email, $phone, $message)
    {
        try {
            // Prepare the SQL statement
            $stmt = $this->pdo->prepare(
                "INSERT INTO complaints (first_name, last_name, email, phone, message, submitted_at) 
                VALUES (:first_name, :last_name, :email, :phone, :message, :submitted_at)"
            );

            // Execute the statement with parameters
            $stmt->execute([
                ':first_name' => $firstName,
                ':last_name' => $lastName,
                ':email' => $email,
                ':phone' => $phone,
                ':message' => $message,
                ':submitted_at' => date('Y-m-d H:i:s') // Use a full datetime format for `submitted_at`
            ]);

            // Check if the row was inserted
            return $stmt->rowCount() === 1;
        } catch (Exception $e) {
            // Log the exception message for debugging
            error_log($e->getMessage());
            // Return a generic error message
            return 'An error occurred while processing your request.';
        }
    }

    public function viewAllComplaints()
    {
        try {
            // Prepare the SQL statement
            $stmt = $this->pdo->prepare("SELECT * FROM complaints");
            // Execute the statement
            $stmt->execute();
            // Fetch all complaints
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            // Log the exception message for debugging
            error_log($e->getMessage());
            // Return an empty array to indicate failure
            return [];
        }
    }

    public function newComplaints($hours = 24)
    {
        try {
            // Prepare the SQL statement
            $stmt = $this->pdo->prepare(
                "SELECT * FROM complaints WHERE submitted_at >= NOW() - INTERVAL :hours HOUR"
            );
            // Execute the statement with parameters
            $stmt->execute([':hours' => $hours]);
            // Fetch the new complaints
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            // Log the exception message for debugging
            error_log($e->getMessage());
            // Return an empty array to indicate failure
            return [];
        }
    }
}
