<?php
class Innovation
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    public function storeInnovations($name, $age, $email, $mobile, $innovation_title, $innovation_idea)
    {
        try {
            // Prepare the SQL statement
            $stmt = $this->pdo->prepare(
                "INSERT INTO innovation_applicants (name, age, email, mobile, innovation_title, innovation_idea, submitted_at ) 
                VALUES (:name, :age, :email, :mobile, :innovation_title, :innovation_idea, :submitted_at)"
            );

            // Execute the statement with parameters
            $stmt->execute([
                ':name' => $name,
                ':age' => $age,
                ':email' => $email,
                ':mobile' => $mobile,
                ':innovation_title' => $innovation_title,
                ':innovation_idea' => $innovation_idea,
                ':submitted_at' => date('Y-m-d H:i:s') // Use a full datetime format for `submitted_at`
            ]);

            // Check if the row was inserted
            return $stmt->rowCount() === 1;
        } catch (Exception $e) {
            // Log the exception message for debugging
            error_log($e->getMessage());
            // Return a generic error message
            return 'An error occurred while processing your request.';
        }
    }

    public function viewAllInnovations()
    {
        try {
            // Prepare the SQL statement
            $stmt = $this->pdo->prepare("SELECT * FROM  innovation_applicants");
            // Execute the statement
            $stmt->execute();
            // Fetch all complaints
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            // Log the exception message for debugging
            error_log($e->getMessage());
            // Return an empty array to indicate failure
            return [];
        }
    }

    public function newInnovations($hours = 24)
    {
        try {
            // Prepare the SQL statement
            $stmt = $this->pdo->prepare(
                "SELECT * FROM innovation_applicants WHERE submitted_at >= NOW() - INTERVAL :hours HOUR"
            );
            // Execute the statement with parameters
            $stmt->execute([':hours' => $hours]);
            // Fetch the new complaints
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            // Log the exception message for debugging
            error_log($e->getMessage());
            // Return an empty array to indicate failure
            return [];
        }
    }
}
