<?php
class RidesEvents
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    public function getGalleryImages()
    {
        try {
            $stmt = $this->pdo->prepare("SELECT image_path FROM rides_event_wallpaper LIMIT 6");
            $stmt->execute();
            $images = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $images;
        } catch (PDOException $e) {
            echo "Error fetching images: " . $e->getMessage(); // Output detailed error message
            return []; // Return an empty array in case of error
        }
    }

    public function getAllGalleryImages()
    {
        try {
            $stmt = $this->pdo->prepare("SELECT image_path FROM rides_event_wallpaper ");
            $stmt->execute();
            $gallary = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $gallary;
        } catch (PDOException $e) {
            echo "Error fetching images: " . $e->getMessage(); // Output detailed error message
            return []; // Return an empty array in case of error
        }
    }


    public function getEvents()
    {
        try {
            $stmt = $this->pdo->prepare("SELECT * FROM rides_event_events");
            $stmt->execute();
            $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
            return $result;
        } catch (PDOException $e) {
            echo "Error fetching events: " . $e->getMessage();
            return [];
        }
    }

    public function createBooking($event_id, $full_name, $mobile, $email)
    {
        try {
            $stmt = $this->pdo->prepare("INSERT INTO event_bookings (event_id, full_name, mobile, email, created_at) VALUES (:event_id, :full_name, :mobile, :email, NOW())");
            $stmt->bindParam(':event_id', $event_id);
            $stmt->bindParam(':full_name', $full_name);
            $stmt->bindParam(':mobile', $mobile);
            $stmt->bindParam(':email', $email);
            $stmt->execute();
            return true; // Return true if the insert was successful
        } catch (PDOException $e) {
            echo "Error creating booking: " . $e->getMessage();
            return false; // Return false in case of error
        }
    }
    public function stayUpdatedForm($name, $email, $mobile, $pincode, $agreed_to_terms)
    {
        try {
            $stmt = $this->pdo->prepare("INSERT INTO stay_updated (name, email, mobile, pincode, agreed_to_terms) VALUES (?, ?, ?, ?, ?)");
            $stmt->execute([$name, $email, $mobile, $pincode, $agreed_to_terms]);
            return true; // Return true if the insert was successful
        } catch (PDOException $e) {
            // Log or output the detailed error message
            error_log("Error: " . $e->getMessage());
            echo "Error: " . $e->getMessage();
            return false; // Return false if there was an error
        }
    }


    //                 Rides and events news function starts here 


    public function getAllNews()
    {
        $stmt = $this->pdo->prepare("SELECT * FROM rides_event_news ORDER BY created_at DESC");
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }


    public function getNewsById($id)
    {
        // Fetch news by ID
        $stmt = $this->pdo->prepare("SELECT * FROM rides_event_news WHERE id = :id");
        $stmt->execute(['id' => $id]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    public function getRelatedNews($excludeId)
    {
        // Fetch related news, excluding the current one
        $stmt = $this->pdo->prepare("SELECT * FROM rides_event_news WHERE id != :excludeId ORDER BY created_at DESC LIMIT 5");
        $stmt->execute(['excludeId' => $excludeId]);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
}
