<?php
require 'header.php';
require 'config.php';
require 'model/rides_events.php';

// Create a new instance of your model
$newsModel = new RidesEvents($pdo);

// Get the news ID from the URL parameter
$newsId = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($newsId > 0) {
    // Fetch the news item based on the ID
    $newsItem = $newsModel->getNewsById($newsId);

    if ($newsItem) {
        $title = htmlspecialchars($newsItem['title'], ENT_QUOTES, 'UTF-8');
        $subheading = htmlspecialchars($newsItem['subheading'], ENT_QUOTES, 'UTF-8');
        $content = htmlspecialchars($newsItem['content'], ENT_QUOTES, 'UTF-8');
        $photoPath = '../static/ridesandevents/news-static/' . rawurlencode($newsItem['photo_path']);
        
        // Fetch related news
        $relatedNews = $newsModel->getRelatedNews($newsId);
    } else {
        echo "News item not found.";
        exit;
    }
} else {
    echo "Invalid news ID.";
    exit;
}
?>
<style>
    body {
        background-color: #f4f4f4;
        color: #333;
        font-family: 'Open Sans', sans-serif;
    }

    .news-title {
        font-family: 'Poppins', sans-serif;
        font-size: 2.8rem;
        font-weight: 800;
        color: #333;
        text-align: center;
        margin-bottom: 2rem;
        position: relative;
        text-transform: uppercase;
        letter-spacing: 1px;
    }

    .news-title::after {
        content: '';
        position: absolute;
        width: 60px;
        height: 4px;
        background-color: #d9534f;
        bottom: -10px;
        left: 50%;
        transform: translateX(-50%);
    }

    .news-image {
        border-radius: 10px;
        box-shadow: 0px 6px 20px rgba(0, 0, 0, 0.15);
        margin-bottom: 2rem;
        width: 100%;
        max-height: 450px;
        object-fit: cover;
        transition: transform 0.3s ease-in-out;
    }

    .news-image:hover {
        transform: scale(1.05);
    }

    .news-content {
        font-size: 1.2rem;
        line-height: 1.8;
        color: #555;
        margin-bottom: 2rem;
    }

    .lead {
        font-size: 1.4rem;
        font-weight: 300;
        color: #666;
        margin-bottom: 2rem;
    }

    .sidebar {
        background-color: #fff;
        padding: 20px;
        border-radius: 10px;
        box-shadow: 0px 4px 15px rgba(0, 0, 0, 0.1);
        transition: transform 0.3s ease-in-out;
    }

    .sidebar:hover {
        transform: translateY(-5px);
    }

    .sidebar h4 {
        font-family: 'Roboto', sans-serif;
        font-size: 1.7rem;
        color: #d9534f;
        margin-bottom: 1.5rem;
    }

    .sidebar ul {
        padding-left: 0;
        list-style: none;
    }

    .sidebar ul li {
        margin-bottom: 1rem;
    }

    .sidebar ul li a {
        font-size: 1.1rem;
        color: #d9534f;
        text-decoration: none;
        transition: color 0.3s;
    }

    .sidebar ul li a:hover {
        color: #c9302c;
    }

    .marquee {
        background-color: #333;
        color: #fff;
        padding: 10px;
        font-size: 1.1rem;
        border-radius: 5px;
        margin-bottom: 20px;
        font-family: 'Roboto', sans-serif;
    }

    .marquee span {
        color: #d9534f;
        font-weight: bold;
        margin-left: 15px;
    }

    @media (max-width: 767px) {
        .news-title {
            font-size: 2.2rem;
        }

        .news-image {
            margin-bottom: 1.5rem;
            max-height: 300px;
        }

        .news-content, .lead {
            font-size: 1.1rem;
        }

        .sidebar h4 {
            font-size: 1.5rem;
        }

        .sidebar ul li a {
            font-size: 1rem;
        }

        .marquee {
            font-size: 1rem;
        }
    }
</style>

<div class="container my-5 pt-5">
    <!-- Marquee for Breaking News or Headlines -->
    <div class="row">
        <div class="col-12">
            <div class="marquee">
                <marquee behavior="scroll" direction="left" id="breakingNewsMarquee">Breaking News: Major updates in the world of motorcycles! <span>New Models Released</span> | <span>Exclusive Reviews</span> | <span>Industry Insights</span></marquee>
            </div>
        </div>
    </div>

    <div class="row">
        <div class="col-12">
            <!-- News Title -->
            <h1 class="news-title"><?php echo $title; ?></h1>
        </div>
    </div>
    <div class="row">
        <div class="col-md-8">
            <!-- News Image -->
             <img src="../../static/ridesandevents/news-static/<?php echo htmlspecialchars($newsItem['photo_path']); ?>" alt="News Image" class="img-fluid">
            
            <!-- News Content -->
            <p class="lead">
                <?php echo $subheading; ?>
            </p>
            <p class="news-content">
                <?php echo nl2br($content); ?>
            </p>
        </div>
        <div class="col-md-4">
            <!-- Sidebar or Related News -->
            <div class="sidebar">
                <h4>Related News</h4>
                <ul>
                    <?php foreach ($relatedNews as $news): ?>
                        <li><a href="rides_event_news.php?id=<?php echo htmlspecialchars($news['id']); ?>"><?php echo htmlspecialchars($news['title']); ?></a></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        </div>
    </div>
</div>

<script>
    const marquee = document.getElementById('breakingNewsMarquee');

    marquee.addEventListener('mouseover', function() {
        marquee.stop();
    });

    marquee.addEventListener('mouseout', function() {
        marquee.start();
    });

    marquee.addEventListener('touchstart', function() {
        marquee.stop();
    });

    marquee.addEventListener('touchend', function() {
        marquee.start();
    });
</script>

<?php include('footer.php'); ?>
