<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Bike Models</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/spritespin/4.0.5/spritespin.min.css">
    <style>
        .model-selection, .color-selection {
            margin-bottom: 20px;
        }
        .bike-360-view {
            width: 100%;
            max-width: 600px;
            height: auto;
            margin: 0 auto;
            background-color: #f8f9fa;
            border-radius: 10px;
        }
        .specifications {
            margin-top: 20px;
            padding: 15px;
            background: #f8f9fa;
            border-radius: 8px;
        }
        .buttons .btn {
            margin-right: 10px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="row">
            <div class="col-lg-6 text-center">
                <div class="model-selection">
                    <select id="modelSelect" class="form-control">
                        <option value="model1">Model 1</option>
                        <option value="model2">Model 2</option>
                        <option value="model3">Model 3</option>
                        <option value="model4">Model 4</option>
                    </select>
                </div>
                <div class="color-selection">
                    <button class="btn btn-outline-dark color-btn" data-color="red">Red</button>
                    <button class="btn btn-outline-dark color-btn" data-color="blue">Blue</button>
                    <button class="btn btn-outline-dark color-btn" data-color="black">Black</button>
                    <!-- Add more colors as needed -->
                </div>
                <div id="bike360View" class="bike-360-view"></div>
                <div class="buttons mt-4">
                    <button class="btn btn-primary">Explore Now</button>
                    <button class="btn btn-success">Book Now</button>
                </div>
            </div>
            <div class="col-lg-6">
                <h3>Specifications</h3>
                <div class="specifications" id="specifications">
                    <!-- Specifications will be loaded dynamically based on the model -->
                </div>
            </div>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/spritespin/4.0.5/spritespin.min.js"></script>
    <script>
        var models = {
            model1: {
                colors: {
                    red: ['images/model1/red/1.jpg', 'images/model1/red/2.jpg', 'images/model1/red/3.jpg'],
                    blue: ['images/model1/blue/1.jpg', 'images/model1/blue/2.jpg', 'images/model1/blue/3.jpg'],
                    black: ['images/model1/black/1.jpg', 'images/model1/black/2.jpg', 'images/model1/black/3.jpg']
                },
                specs: '<ul><li>Engine: 150cc</li><li>Max Power: 13.4 hp @ 8500 rpm</li><li>Fuel Tank Capacity: 12L</li></ul>'
            },
            model2: {
                colors: {
                    red: ['images/model2/red/1.jpg', 'images/model2/red/2.jpg', 'images/model2/red/3.jpg'],
                    blue: ['images/model2/blue/1.jpg', 'images/model2/blue/2.jpg', 'images/model2/blue/3.jpg'],
                    black: ['images/model2/black/1.jpg', 'images/model2/black/2.jpg', 'images/model2/black/3.jpg']
                },
                specs: '<ul><li>Engine: 180cc</li><li>Max Power: 15.6 hp @ 9000 rpm</li><li>Fuel Tank Capacity: 15L</li></ul>'
            }
            // Add more models as needed
        };

        function loadBikeImages(model, color) {
            $('#bike360View').spritespin({
                source: models[model].colors[color],
                width: 600,
                height: 400,
                animate: false,
                loop: false,
                frame: 0,
                sense: -1
            });
        }

        function loadSpecifications(model) {
            $('#specifications').html(models[model].specs);
        }

        $(document).ready(function() {
            var currentModel = 'model1';
            var currentColor = 'red';

            loadBikeImages(currentModel, currentColor);
            loadSpecifications(currentModel);

            $('#modelSelect').on('change', function() {
                currentModel = $(this).val();
                loadBikeImages(currentModel, currentColor);
                loadSpecifications(currentModel);
            });

            $('.color-btn').on('click', function() {
                currentColor = $(this).data('color');
                loadBikeImages(currentModel, currentColor);
            });
        });
    </script>
</body>
</html>
